Plugins/CheckerPlugins/Pep8/CodeStyleCodeSelectionDialog.py

changeset 2980
2cb4e3c50b37
parent 2979
e2eee1b09664
diff -r e2eee1b09664 -r 2cb4e3c50b37 Plugins/CheckerPlugins/Pep8/CodeStyleCodeSelectionDialog.py
--- a/Plugins/CheckerPlugins/Pep8/CodeStyleCodeSelectionDialog.py	Tue Oct 01 18:34:19 2013 +0200
+++ b/Plugins/CheckerPlugins/Pep8/CodeStyleCodeSelectionDialog.py	Tue Oct 01 18:42:42 2013 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog to select PEP 8 message codes.
+Module implementing a dialog to select code style message codes.
 """
 
 from PyQt4.QtCore import QCoreApplication
@@ -21,7 +21,7 @@
 
 class CodeStyleCodeSelectionDialog(QDialog, Ui_CodeStyleCodeSelectionDialog):
     """
     Class implementing a dialog to select PEP 8 message codes.
     """
     def __init__(self, codes, showFixCodes, parent=None):
         """
@@ -21,7 +21,7 @@
 class CodeStyleCodeSelectionDialog(QDialog, Ui_CodeStyleCodeSelectionDialog):
     """
-    Class implementing a dialog to select PEP 8 message codes.
+    Class implementing a dialog to select code style message codes.
     """
     def __init__(self, codes, showFixCodes, parent=None):

eric ide

mercurial